# frozen_string_literal: true

require 'errors_helper/version'
require 'errors_helper/base'
require 'errors_helper/bad_request'
require 'errors_helper/not_found'
require 'errors_helper/unprocessable_entity'
require 'json'
require 'yaml'

module ErrorsHelper
  @codes = YAML.load_file(File.dirname(__FILE__)+ '/../lib/codes.yml')

  def self.build_response(code:)
    message = @codes.dig('error_code', code)
    return parse(@codes.dig('error_code', '99')) if message.nil?

    parse(message)
  end

  def self.list_errors
    @codes.dig('error_code').each { |key, value| puts "#{key} : #{value}"}
    true
  end

  def self.parse(value)
    JSON.parse(JSON[value], symbolize_names: true)
  end

  private_class_method :parse
end
