# frozen_string_literal: true

require 'active_model'
require 'rack'

module ErrorsHelper
  class Base < StandardError
    include ActiveModel::Serialization
    attr_reader :message, :code

    def initialize(message: ErrorsHelper.build_response(code: '99')[:message],
                   code: ErrorsHelper.build_response(code: '99')[:code],
                   status: nil)
      @message = message
      @code = code
      @status = status
    end

    def to_hash
      {
        message: message,
        code: code
      }.compact
    end

    alias_method 'to_h', 'to_hash'

    def status
      Rack::Utils::SYMBOL_TO_STATUS_CODE[@status]
    end

    def inspect
      "[Code: #{code}] #{message}"
    end
  end
end
